'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactInteractive = require('react-interactive');

var _reactInteractive2 = _interopRequireDefault(_reactInteractive);

var _highlightJs = require('./highlight-js');

var _highlightJs2 = _interopRequireDefault(_highlightJs);

var _atomOneLightStyle = require('./atomOneLightStyle');

var _atomOneLightStyle2 = _interopRequireDefault(_atomOneLightStyle);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var sharedStyle = {
  fontFamily: 'system-ui, Helvetica, sans-serif',
  lineHeight: '1.5',
  wordWrap: 'break-word',
  color: 'black',
  fontSize: '16px',
  boxSizing: 'border-box'
};

var Heading = function Heading(props) {
  var level = props.level;

  var style = _extends({}, Heading.style, {
    fontSize: level === 1 && '32px' || level === 2 && '24px' || level === 3 && '20px' || level === 4 && '16px' || '14px',
    color: level === 6 && 'rgb(100, 100, 100)' || 'black',
    paddingBottom: level <= 2 && '0.3em' || null,
    borderBottom: level <= 2 && '1px solid rgb(216, 216, 216)' || null
  }, props.style);
  var H = 'h' + level;
  return _react2.default.createElement(
    H,
    { style: style },
    props.children
  );
};
Heading.style = _extends({}, sharedStyle, {
  fontWeight: '500',
  margin: '24px 0 16px 0',
  lineHeight: '1.25'
});
Heading.propTypes = {
  level: _propTypes2.default.number.isRequired,
  style: _propTypes2.default.object,
  children: _propTypes2.default.node
};

var Paragraph = function Paragraph(props) {
  var style = props.style ? _extends({}, Paragraph.style, props.style) : Paragraph.style;
  return _react2.default.createElement(
    'p',
    { style: style },
    props.children
  );
};
Paragraph.style = _extends({}, sharedStyle, {
  margin: '0 0 16px 0'
});
Paragraph.propTypes = {
  style: _propTypes2.default.object,
  children: _propTypes2.default.node
};

var Link = function Link(props) {
  return _react2.default.createElement(
    _reactInteractive2.default,
    _extends({ as: 'a', href: props.href, title: props.title }, Link.style),
    props.children
  );
};
Link.style = {
  style: _extends({}, sharedStyle, {
    color: 'rgb(3, 102, 214)',
    backgroundColor: 'transparent',
    textDecoration: 'none'
  }),
  hover: { textDecoration: 'underline' },
  active: 'hover',
  focusFromTab: {
    backgroundColor: 'rgba(3, 102, 214, 0.2)',
    padding: '2px 4px',
    margin: '-2px -4px',
    borderRadius: '3px'
  },
  touchActiveTapOnly: true
};
Link.propTypes = {
  href: _propTypes2.default.string,
  title: _propTypes2.default.string,
  children: _propTypes2.default.node
};

var Image = function Image(props) {
  return _react2.default.createElement('img', { src: props.src, alt: props.alt, title: props.title });
};
Image.propTypes = {
  src: _propTypes2.default.string,
  alt: _propTypes2.default.string,
  title: _propTypes2.default.string
};

// tight prop is if the list items don't have blank lines between them
// if a list is not tight then the contents are automatically wrapped in p tags
// e.g. <li><p>rendered item of loose list</p></li>
// see http://spec.commonmark.org/0.26/#lists for more info
// you don't have to worry about this in your renderer unless you want to
// treat tight/loose lists differently (the p tags are already a part of children)
var List = function List(props) {
  var style = props.style ? _extends({}, List.style, props.style) : List.style;
  if (props.type === 'ordered') {
    return _react2.default.createElement(
      'ol',
      { start: props.start, style: style },
      props.children
    );
  }
  return _react2.default.createElement(
    'ul',
    { style: style },
    props.children
  );
};
List.style = _extends({}, sharedStyle, {
  margin: '0 0 16px',
  paddingLeft: '2em'
});
List.propTypes = {
  type: _propTypes2.default.oneOf(['ordered', 'bullet']).isRequired,
  start: _propTypes2.default.number,
  tight: _propTypes2.default.bool,
  style: _propTypes2.default.object,
  children: _propTypes2.default.node
};

var Item = function Item(props) {
  // check to see if the item contains another list, if it does
  // offset the bottom margin of the list it contains
  var containsList = props.children.some(function (child) {
    return _react2.default.isValidElement(child) && child.type === List;
  });
  var style = _extends({}, Item.style);
  if (containsList) style.margin = '4px 0 -12px';
  return _react2.default.createElement(
    'li',
    { style: style },
    props.children
  );
};
Item.style = {
  margin: '4px 0',
  lineHeight: '1.4'
};
Item.propTypes = {
  children: _propTypes2.default.node
};

var BlockQuote = function BlockQuote(props) {
  var mappedChildren = _react2.default.Children.map(props.children, function (child) {
    return (
      // add style color to children
      _react2.default.cloneElement(child, {
        style: { color: BlockQuote.style.color }
      })
    );
  });
  return _react2.default.createElement(
    'blockquote',
    { style: BlockQuote.style },
    mappedChildren
  );
};
BlockQuote.style = _extends({}, sharedStyle, {
  borderLeft: '4px solid rgb(216, 216, 216)',
  color: 'rgb(100, 100, 100)',
  padding: '0 1em',
  margin: '0 0 1em'
});
BlockQuote.propTypes = {
  children: _propTypes2.default.node
};

var Emph = function Emph(props) {
  return _react2.default.createElement(
    'em',
    { style: Emph.style },
    props.children
  );
};
Emph.style = {
  fontStyle: 'italic'
};
Emph.propTypes = {
  children: _propTypes2.default.node
};

var Strong = function Strong(props) {
  return _react2.default.createElement(
    'strong',
    { style: Strong.style },
    props.children
  );
};
Strong.style = {
  fontWeight: '600'
};
Strong.propTypes = {
  children: _propTypes2.default.node
};

// render softbreak as a space, so omit this renderer
// const Softbreak = () => {
//   // returning null will render text as though the softbreak doesn't exist
//   // to render a line break instead, return <br />;
//   // to render a space, omit this renderer
//   return null;
// };

// a line with 2 spaces at the end followed by a return
var Linebreak = function Linebreak() {
  return _react2.default.createElement('br', null);
};

var ThematicBreak = function ThematicBreak() {
  return _react2.default.createElement('hr', { style: ThematicBreak.style });
};
ThematicBreak.style = {
  border: 'none',
  borderBottom: '4px solid rgb(216, 216, 216)',
  padding: '0',
  margin: '24px 0',
  overflow: 'hidden'
};

var Code = function Code(props) {
  return _react2.default.createElement(
    'code',
    { style: Code.style },
    _react2.default.createElement(
      'span',
      { style: { letterSpacing: '-4px' } },
      '\xA0'
    ),
    props.literal,
    _react2.default.createElement(
      'span',
      { style: { letterSpacing: '-4px' } },
      '\xA0'
    )
  );
};
Code.style = _extends({}, sharedStyle, {
  fontFamily: 'Menlo, Courier, monospace',
  fontSize: '93.75%',
  color: 'inherit',
  backgroundColor: 'rgba(16, 16, 16, 0.05)',
  padding: '2px 0',
  borderRadius: '3px'
});
Code.propTypes = {
  literal: _propTypes2.default.string
};

var CodeBlock = function (_React$Component) {
  _inherits(CodeBlock, _React$Component);

  function CodeBlock() {
    var _ref;

    var _temp, _this, _ret;

    _classCallCheck(this, CodeBlock);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = CodeBlock.__proto__ || Object.getPrototypeOf(CodeBlock)).call.apply(_ref, [this].concat(args))), _this), _this.domNode = null, _this.handleRef = function (domNode) {
      _this.domNode = domNode;
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  _createClass(CodeBlock, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      if (!CodeBlock.syntaxStylesAdded) CodeBlock.addSyntaxStyles();
      _highlightJs2.default.highlightBlock(this.domNode);
    }
  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate() {
      _highlightJs2.default.highlightBlock(this.domNode);
    }
  }, {
    key: 'shouldComponentUpdate',
    value: function shouldComponentUpdate(nextProps) {
      return this.props.literal !== nextProps.literal || this.props.language !== nextProps.language;
    }
  }, {
    key: 'render',
    value: function render() {
      var language = typeof this.props.language === 'string' ? this.props.language.toLowerCase() : null;
      var className = language === 'js' ? 'javascript' : language;
      return _react2.default.createElement(
        'pre',
        { style: CodeBlock.style, ref: this.handleRef, className: className },
        this.props.literal
      );
    }
  }], [{
    key: 'addSyntaxStyles',
    value: function addSyntaxStyles() {
      var style = document.createElement('style');
      style.type = 'text/css';
      style.appendChild(document.createTextNode(_atomOneLightStyle2.default));
      document.getElementsByTagName('head')[0].appendChild(style);
      CodeBlock.syntaxStylesAdded = true;
    }
  }]);

  return CodeBlock;
}(_react2.default.Component);

CodeBlock.syntaxStylesAdded = false;
CodeBlock.style = _extends({}, sharedStyle, {
  fontFamily: 'Menlo, Courier, monospace',
  width: '100%',
  overflow: 'scroll',
  backgroundColor: 'rgba(16, 16, 16, 0.04)',
  borderRadius: '3px',
  fontSize: '14px',
  lineHeight: '1.45',
  padding: '16px',
  margin: '0 0 16px 0',
  wordWrap: 'normal'
});

CodeBlock.propTypes = {
  literal: _propTypes2.default.string,
  language: _propTypes2.default.string
};

exports.default = {
  renderers: {
    Heading: Heading,
    Paragraph: Paragraph,
    Link: Link,
    Image: Image,
    List: List,
    Item: Item,
    BlockQuote: BlockQuote,
    Emph: Emph,
    Strong: Strong,
    Linebreak: Linebreak,
    ThematicBreak: ThematicBreak,
    Code: Code,
    CodeBlock: CodeBlock
  }
};
module.exports = exports['default'];